<?php
/**
 * vintagejournal functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package vintagejournal
 */
ob_start();

if ( defined( 'WP_DEBUG' ) && true == WP_DEBUG ) {
	error_reporting( E_ALL );
} else {
	error_reporting( 0 );
}

if ( ! function_exists( 'vintagejournal_setup_setup' ) ) :
	/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
	function vintagejournal_setup_setup() {
		/* Admin functionality */
		if ( is_admin() ) {
			// Getting Started page and EDD update class
			require_once( get_template_directory() . '/inc/admin/get-started.php' );
		}
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on vintagejournal, use a find and replace
		 * to change 'vintagejournal' to the name of your theme in all the template files.
		 */

		/* inclide localization file */
		load_theme_textdomain( 'vintagejournal', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'vintagejournal' ),
			'secondary' => esc_html__( 'Secondary', 'vintagejournal' ),
			'footer' => esc_html__( 'footer', 'vintagejournal' ),
		) );

			/*
             * Switch default core markup for search form, comment form, and comments
             * to output valid HTML5.
			 */
			add_theme_support( 'html5', array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			) );

			/*
             * Enable support for Post Formats.
             * See https://developer.wordpress.org/themes/functionality/post-formats/
			 */
			add_theme_support( 'post-formats', array(
				'aside',
				'image',
				'video',
				'audio',
				'quote',
				'link',
			) );

			// Set up the WordPress core custom background feature.
			add_theme_support( 'custom-background', apply_filters( 'vintagejournal_custom_background_args', array(
				'default-color' => 'ffffff',
				'default-image' => '',
			) ) );

			add_theme_support( 'custom-header', apply_filters( 'vintagejournal_custom_header_args', array(
				'width'                  => 1900,
				'height'                 => 280,
				'flex-height'            => true,
			) ) );

			/**
	 * Set the content width in pixels, based on the theme's design and stylesheet.
	 *
	 * Priority 0 to make it available to lower priority callbacks.
	 *
	 * @global int $content_width
	 */
			 $GLOBALS['content_width'] = apply_filters( 'vintage_content_width', 640 );
	}
endif;
add_action( 'after_setup_theme', 'vintagejournal_setup_setup' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function vintagejournal_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'vintagejournal' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Homepage Slider', 'vintagejournal' ),
		'id'            => 'home-slider',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Top Menu Right Side', 'vintagejournal' ),
		'id'            => 'top_menu_right',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Header Right', 'vintagejournal' ),
		'id'            => 'header_right',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Header Bottom', 'vintagejournal' ),
		'id'            => 'header_bottom',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Below Header Bottom', 'vintagejournal' ),
		'id'            => 'below_header_bottom',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Above Footer', 'vintagejournal' ),
		'id'            => 'above-footer',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Instagram', 'vintagejournal' ),
		'id'            => 'footer_top',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Right Side', 'vintagejournal' ),
		'id'            => 'footer_right',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

}
add_action( 'widgets_init', 'vintagejournal_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function vintagejournal_scripts() {

	wp_enqueue_style( 'vintagejournal-style', get_stylesheet_uri() );

	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css' );

	// modernizr (without media query polyfill)
	wp_enqueue_script( 'vintagejournal-menu', get_stylesheet_directory_uri() . '/js/menu.js', array(), '', true );

	wp_enqueue_style( 'vintagejournal-menu', get_template_directory_uri() . '/css/menu.css' );

	wp_enqueue_style( 'vintagejournal-animate', get_template_directory_uri() . '/css/animate.css' );

	if ( is_front_page() || is_home()  || get_query_var( 'page_id' ) == get_option( 'page_on_front' ) ) {
		wp_enqueue_script( 'owl.carousel', get_stylesheet_directory_uri() . '/js/owl.carousel.js', array(), '', true );
		wp_enqueue_style( 'owl.carousel', get_template_directory_uri() . '/css/owl.carousel.css' );
	}

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_script( 'jquery', false, array(), false, false );

}
add_action( 'wp_enqueue_scripts', 'vintagejournal_scripts' );

/*editor style css*/
function vintagejournal_editor_styles() {
	add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'vintagejournal_editor_styles' );


add_action( 'wp_enqueue_scripts', 'vintagejournal_common_scripts' );
add_action( 'admin_enqueue_scripts', 'vintagejournal_common_scripts' );

function vintagejournal_common_scripts() {

	wp_enqueue_script( 'vintagejournal-script', get_stylesheet_directory_uri() . '/js/vintagejournal-script.js', array(), '', true );

	$vintagejournal_settings = get_option( vintagejournal_prefix() . '_theme_settings' );

	if ( isset( $vintagejournal_settings['vintagejournal_google_fonts'] ) ) {
		@$vintagejournal_google_fonts = $vintagejournal_settings['vintagejournal_google_fonts'];
		if ( isset( $vintagejournal_google_fonts ) && $vintagejournal_google_fonts != '' ) {
			if ( strstr( $vintagejournal_google_fonts,'+' ) ) {
				$css_gogole_font = str_replace( '+',' ',$vintagejournal_google_fonts );
			} else {
				$css_gogole_font = $vintagejournal_google_fonts;
			}

			wp_enqueue_style( 'google-fonts', vintagejournal_google_fonts_url( $vintagejournal_google_fonts ), array(), '1.0.0' );

			$style = ' html body, body .accordion dd > a, body button, body .button, body .label, body .pricing-table .title, body .pricing-table .price, body .side-nav, body .side-nav li.active > a:first-child:not(.button), body .sub-nav dt, body .sub-nav dd, body .sub-nav li, body .tabs dd > a, body .top-bar-section ul li > a, body h1, body h2, body h3, body h4, body h5, body h6, body .commentlist .comment-reply-link{font-family: ' . $css_gogole_font . ', sans-serif;}';

			wp_add_inline_style( 'vintagejournal-style',$style );

		}
	}

	if ( isset( $vintagejournal_settings['vintagejournal_fonts_size'] ) ) {
		@$vintagejournal_google_fonts_size = $vintagejournal_settings['vintagejournal_fonts_size'];
		if ( @$vintagejournal_google_fonts_size ) {
			$style = 'html, body{font-size: ' . $vintagejournal_google_fonts_size . 'px !important;}';
			wp_add_inline_style( 'vintagejournal-style',$style );
		}
	}

}

/* Add google fonts */
function vintagejournal_google_fonts_url( $fonts ) {

	$font_url = '';

	$font_url = add_query_arg( 'family', urlencode( $fonts ), '//fonts.googleapis.com/css' );

	return $font_url;

}


/* Include all widget files */
foreach ( glob( get_template_directory() . '/widgets/*.php' ) as $filename ) {
	require_once $filename;
}

/*
* Custom widgets Settings
*/
add_action( 'widgets_init','vintagejournal_custom_widgets' ); // register new widgets

function vintagejournal_custom_widgets() {
	 register_widget( 'Vintagejournal_Widget_Popular_Posts' );
	 register_widget( 'Vintagejournal_Widget_Latest_Posts' );
	 register_widget( 'Vintagejournal_Adv_Widget' );
	 register_widget( 'Vintagejournal_Social_Media' );
	 register_widget( 'Vintagejournal_Subscriber_Widget' );
	 register_widget( 'Vintagejournal_Author_Widget' );
	register_widget( 'Vintagejournal_My_Book' );
	register_widget( 'Vintagejournal_Post_Slider' );
	register_widget( 'Vintagejournal_Editor_Slider' );
	register_widget( 'Vintagejournal_Post_Category' );
	register_widget( 'Vintagejournal_Widget_Categories' );
	register_widget( 'Vintagejournal_Widget_Tag_Cloud' );
}

function vintagejournal_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	//adds a class of
	return $classes;
}

add_filter( 'body_class', 'vintagejournal_body_classes' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/*Comment */
function vintagejournal_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	extract( $args, EXTR_SKIP );

	if ( 'div' == $args['style'] ) {
		$tag = 'div';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'div-comment';
	}
?>
	<<?php echo esc_attr( $tag ) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
	<?php if ( 'div' != $args['style'] ) : ?>
	<div id="div-comment-<?php intval( comment_ID() ) ?>" class="comment-body">
	<?php endif; ?>
	<div class="comment-author vcard">
	<?php if ( $args['avatar_size'] != 0 ) { echo get_avatar( $comment, $args['avatar_size'] );} ?>
	<?php printf( ( '<cite class="fn">%s</cite>' ), get_comment_author_link() ); ?>

	<div class="comment-meta commentmetadata">
		<a href="<?php echo htmlspecialchars( get_comment_link(
		$comment->comment_ID ) ) ?>"><?php printf( __( '%1$s at %2$s','vintagejournal' ), get_comment_date(),  get_comment_time() ) ?>
		</a>
		<?php edit_comment_link( esc_html__( '(Edit)','vintagejournal' ),'  ','' ) ?>
	</div>       
	</div>
	<?php if ( $comment->comment_approved == '0' ) : ?>
		<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.','vintagejournal' ); ?></em>
		<br />
	<?php endif; ?>
	
	<div class="comment-meta comment-footer edit-reply">
	<?php comment_reply_link( array_merge( $args, array(
		'add_below' => esc_attr( $add_below ),
		'depth' => intval( $depth ),
		'max_depth' => intval( $args['max_depth'] ),
	) ) ); ?>
	</div>
	<div class="comment-content">
		<?php comment_text(); ?>
	</div>
	
	<?php if ( 'div' != $args['style'] ) : ?>
	</div>
	<?php endif; ?>

<?php
}

add_filter( 'wp_nav_menu_args', 'vintagejournal_nav_menu_args' );
function vintagejournal_nav_menu_args( $args = '' ) {
	$args['container'] = false;
	return $args;
}

if ( ! function_exists( 'vintagejournal_reverse_strrchr' ) ) {
	function vintagejournal_reverse_strrchr( $haystack, $needle, $trail ) {
		return strrpos( $haystack, $needle ) ? substr( $haystack, 0, strrpos( $haystack, $needle ) + $trail ) : false;
	}
}

if ( ! function_exists( 'vintagejournal_print_excerpt' ) ) {
	function vintagejournal_print_excerpt( $length ) {
		// Max excerpt length. Length is set in characters
		global $post;
		$length = ($length == '')? '50' : $length;
		/*condition for supreme related theme*/

		$text = $post->post_excerpt;
		if ( $text == '' ) {
			$text = $post->post_content;
			$text = apply_filters( 'the_excerpt', $text );
			$text = str_replace( ']]>', ']]>', $text );
		}
		$text = strip_shortcodes( $text ); // optional, recommended
		$text = strip_tags( $text ); // use ' $text = strip_tags($text,'<p><a>'); ' if you want to keep some tags

		$text = wp_trim_words( $text,$length ); /* shows perticular words */
		if ( vintagejournal_reverse_strrchr( $text, '.', 1 ) ) {
			$excerpt = vintagejournal_reverse_strrchr( $text, '.', 1 );
		} else {
			$excerpt = $text;
		}

		if ( $excerpt ) {
			echo apply_filters( 'the_excerpt',$excerpt );
		} else {
			echo apply_filters( 'the_excerpt',$text );
		}
	}
}

function vintagejournal_post_first_image() {
	global $post;
	if ( has_post_thumbnail() ) {
		$thumb_id = get_post_thumbnail_id();
		$thumb_url_array = wp_get_attachment_image_src( $thumb_id, 'full', true );
		$first_img = $thumb_url_array[0];
	} else {
		$first_img = '';
		$output = preg_match_all( '/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches );

		if ( ! empty( $matches [1] [0] ) ) {
			$first_img = @$matches [1] [0];
			if ( empty( $first_img ) ) { //Defines a default image
				$first_img = get_template_directory_uri() . '/images/templatic-home-page-banner.png';
			}
			if ( ! preg_match( '~^(?:f|ht)tps?://~i', $first_img ) ) {
				$first_img = 'https:' . $first_img;
			}
		}
	}
	?>
  <span itemprop="image" itemscope itemtype="https://schema.org/ImageObject">
		<meta itemprop="url" content="<?php echo wp_kses( $first_img, wp_kses_allowed_html( 'post' ) ); ?>">
		<meta itemprop='width' content='500'/>
		<meta itemprop='height' content='500'/>  
  </span>
	<?php
}

if ( ! function_exists( 'vintagejournal_page_posted_on' ) ) :

	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function vintagejournal_page_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		}

		$time_string = sprintf($time_string, esc_attr( get_the_date( 'c' ) ), esc_html( get_the_date() ), esc_attr( get_the_modified_date( 'c' ) ), esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			esc_html__( 'Posted on %s', 'vintagejournal' ), '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark"><span datetime="' . get_the_time( 'c' ) . '" itemprop="datePublished" content="' . get_the_time( 'c' ) . '">' . $time_string . '</span></a>'
		);

		$byline = sprintf(
			esc_html__( 'by %s', 'vintagejournal' ), '<span class="author vcard" itemprop="author" itemscope itemtype="https://schema.org/Person">' . esc_html( get_the_author() ) . ' <span itemprop="name">Templatic</span></span>'
		);

		echo '<span class="posted-on hide_class">' . $posted_on . '</span><span class="byline hide_class"> ' . $byline . '</span>'; // WPCS: XSS OK.
	}

endif;

function vintagejournal_structured_data() {
	?>
	<div class="publisher-img" itemprop="publisher" itemscope itemtype="https://schema.org/Organization">
	<div itemprop="logo" itemscope itemtype="https://schema.org/ImageObject">
	  <meta itemprop="url" content="<?php echo get_stylesheet_directory_uri() ?>/images/logo.png">
	  <meta itemprop="width" content="100">
	  <meta itemprop="height" content="100">
	</div>
	<meta itemprop="name" content="<?php echo get_bloginfo( 'name' ); ?>">
	</div>
	<meta itemprop="dateModified" content="<?php echo get_the_time( 'c' ); ?>"/>
	<?php
}

function vintagejournal_display_related_post() {
	global $post;
	$categories = get_the_category();
	if ( $categories ) {
		foreach ( $categories as $category ) {
			$cat[] = $category->cat_ID;
		}
			$args = array(
			'cat' => $cat,
			'order' => 'DESC',
			'orderby' => 'rand',
			'post__not_in' => array( $post->ID ),
			'posts_per_page' => 3,
		);
		$related_query = null;
		$related_query = new WP_Query( $args );
		if ( $related_query->have_posts() ) {
			echo '<div class="related_posts">';
			echo '<h3>' . esc_html__( 'You may also like','vintagejournal' ) . '</h3>';
			echo '<ul>';
			while ( $related_query->have_posts() ) : $related_query->the_post(); ?>
			<li>
				<div class="post_img"><a class="post-thumb" href="<?php echo esc_url( get_permalink() ) ?>" rel="bookmark">
				<?php
				if ( get_the_post_thumbnail_url( $post,'medium' ) ) {
					?><img src="<?php esc_url( the_post_thumbnail_url( 'medium' ) ); ?>" alt="<?php echo esc_attr( get_the_title() );?>" />
				<?php
				} else {
					?>
					<img src="<?php echo get_stylesheet_directory_uri() ?>/images/noimage.jpg" alt="<?php echo esc_attr( get_the_title() );?>" />
				<?php
				}
				?>
				</a></div>
			 
				<div class="post_title">
				<a class="post-thumb" href="<?php echo esc_url( get_permalink() ) ?>" rel="bookmark"><?php esc_attr( the_title() ); ?></a>
			<span class="category"><?php
				$related_categories = get_the_category();
				$last = count( $related_categories );
				$count = 0;
				$category_html = '';
			foreach ( $related_categories as $related_cat ) {
				$count++;
				if ( $count == $last ) {
					$category_html .= '<a href="' . esc_url( get_term_link( $related_cat->term_id ) ) . '">' . esc_html( $related_cat->name ) . '</a>';
				} else {
					$category_html .= '<a href="' . esc_url( get_term_link( $related_cat->term_id ) ) . '">' . esc_html( $related_cat->name ) . '</a> <span class="hr">/</span> ';
				}
			}
				echo wp_kses( $category_html, wp_kses_allowed_html( 'post' ) );
				?></span>
				</div>
			</li>
				<?php
				endwhile;
			wp_reset_query();
			wp_reset_postdata();
			echo '</div></ul>';
		}// End if().
	}// End if().
}

add_action( 'wp_head', 'vintagejournal_customizer_style' );
/* add customiser css in front style.css */
if ( ! function_exists( 'vintagejournal_customizer_style' ) ) {

	function vintagejournal_customizer_style() {

		if ( file_exists( get_stylesheet_directory() . '/admin-style.php' ) ) {
			include_once( get_stylesheet_directory() . '/admin-style.php' ); // child theme css file
		} elseif ( file_exists( get_template_directory() . '/front-style.php' ) ) {
			include_once( get_template_directory() . '/front-style.php' );
		}
	}
}

include_once( get_template_directory() . '/admin.php' );

function vintagejournal_prefix() {
	return 'vintagejournal';
}

add_action( 'wp_head','vintagejournal_global_settings' );

function vintagejournal_global_settings() {
	global $vintagejournal_settings;
	$vintagejournal_settings = get_option( vintagejournal_prefix() . '_theme_settings' );
	return $vintagejournal_settings;
}
add_action( 'customize_register' , 'vintagejournal_customizer_footer_options',100 );

function vintagejournal_customizer_footer_options( $wp_customize ) {
	global $wp_customize;

	$wp_customize->remove_section( 'header_image' );

	$wp_customize->add_section( 'vintagejournal_logo_section' , array(
			'title'       => esc_html__( 'Site Logo', 'vintagejournal' ),
			'priority'    => 30,
			'description' => esc_html__( 'Upload a logo to replace the default site name and description in the header','vintagejournal' ),
	) );

	$wp_customize->add_section(
		'vintagejournal_footer_options',
		array(
			'title'       => esc_html__( 'Footer Settings', 'vintagejournal' ),
			'priority'    => 100,
			'capability'  => 'edit_theme_options',
			'description' => esc_html__( 'Change footer options here.', 'vintagejournal' ),
		)
	);

	//adding setting for footer text area
	$wp_customize->add_setting('footer_text', array(
		'default'        => esc_html__( 'Default Text For Footer Section','vintagejournal' ),
		'sanitize_callback' => 'vintagejournal_footer_options',
	));

	$wp_customize->add_control('footer_text', array(
		'label'   => esc_html__( 'Footer Text Here','vintagejournal' ),
		'section' => 'vintagejournal_footer_options',
		'type'    => 'textarea',
	));

	$wp_customize->add_section('homepage_settings_section', array(
		'title'          	=> esc_html__( 'Homepage banner after second post', 'vintagejournal' ),
		'priority'    	=> 40,
	));
	//adding setting for footer text area
	$wp_customize->add_setting('homepage_first_banner', array(
		'default'        		=> '',
		'sanitize_callback' 	=> 'vintagejournal_footer_options',
	));
	$wp_customize->add_control('homepage_first_banner', array(
		'label'   => esc_html__( 'Homepage banner after second post', 'vintagejournal' ),
		'section' => 'homepage_settings_section',
		'type'    => 'textarea',
	));

	//adding setting for footer text area
	$wp_customize->add_setting('homepage_second_banner', array(
		'default'        => '',
		'sanitize_callback' => 'vintagejournal_footer_options',
	));
	$wp_customize->add_control('homepage_second_banner', array(
		'label'   => esc_html__( 'Homepage banner after fourth post', 'vintagejournal' ),
		'section' => 'homepage_settings_section',
		'type'    => 'textarea',
	));

	/**
	 * Sanitizes the footer content on the customize screen.  Users with the 'unfiltered_html' cap can post
	 * anything.  For other users, wp_filter_post_kses() is ran over the setting.
	 * @param mixed $setting The current setting passed to sanitize.
	 * @param object $object The setting object passed via WP_Customize_Setting.
	 * @return mixed $setting
	 */
	function vintagejournal_footer_options( $setting, $object ) {
		/* Get the theme prefix. */
		$prefix = 'vintagejournal';
		/* Make sure we kill evil scripts from users without the 'unfiltered_html' cap. */
		if ( 'lifestyle_footer[footer_text]' == $object->id && ! current_user_can( 'unfiltered_html' ) ) {
			$setting = stripslashes( wp_filter_post_kses( addslashes( $setting ) ) );
		}
		/* Return the sanitized setting and apply filters. */
		return apply_filters( "{$prefix}_customize_sanitize", $setting, $object );
	}
}

/* Register new image sizes. */
function vintagejournal_register_image_sizes() {

	/* slider images */
	add_image_size( 'vintagejournal-slider-image', 640, 525, true );

	/* add medium sized image */
	add_image_size( 'vintagejournal-category-thumb', 279, 279, true );

	/* add featured sized image */
	add_image_size( 'vintagejournal-featured-image', 970, 546, true );

	add_image_size( 'vintagejournal-post-small-thumb', 110, 80, true );

	add_image_size( 'vintagejournal-post-medium', 225, 185, true );

	update_option( 'large_size_w', 0 );
	update_option( 'large_size_h', 0 );
	update_option( 'medium_size_w', 0 );
	update_option( 'medium_size_h', 0 );
	update_option( 'medium_large_size_w', 0 );
	update_option( 'medium_large_size_h', 0 );
	update_option( 'thumbnail_size_h', 0 );
	update_option( 'thumbnail_size_w', 0 );

}

add_action( 'init', 'vintagejournal_register_image_sizes',10 );

function vintagejournal_remove_scroll_link( $link ) {
	$link = '';
	return $link;
}
add_filter( 'excerpt_more', 'vintagejournal_remove_scroll_link' );

/* call a function to add image upload for category icon */

add_action( 'admin_init','vintagejournal_add_category_icon' );

add_action( 'admin_enqueue_scripts', 'vintagejournal_admin_enqueue_assets' );

add_action( 'edit_term', 'vintagejournal_save_image' );
add_action( 'create_term', 'vintagejournal_save_image' );

if ( ! function_exists( 'vintagejournal_admin_enqueue_assets' ) ) {
	function vintagejournal_admin_enqueue_assets( $hook ) {
		if ( $hook != 'edit-tags.php' && $hook != 'term.php' ) {
			return;
		}

		wp_enqueue_media();

		wp_enqueue_script(
			'vintagejournal-category-image-js',
			get_template_directory_uri() . '/js/categoryimage.js',
			array( 'jquery' ),
			'1.0.0',
			true
		);

		wp_localize_script(
			'vintagejournal-category-image-js',
			'CategoryImage',
			array(
				'label'      => array(
					'title'  => esc_html__( 'Choose Category Image', 'vintagejournal' ),
					'button' => esc_html__( 'Choose Image', 'vintagejournal' ),
				),
			)
		);

		wp_enqueue_style(
			'vintagejournal-category-image-css',
			get_template_directory_uri() . '/css/categoryimage.css'
		);
	}
}

if ( ! function_exists( 'vintagejournal_add_category_icon' ) ) {
	function vintagejournal_add_category_icon() {
		$taxonomies = get_taxonomies();

		add_filter( 'manage_edit-category_columns', 'vintagejournal_manage_category_columns' );
		add_filter( 'manage_category_custom_column', 'vintagejournal_manage_category_columns_fields', 10, 3 );

		foreach ( (array) $taxonomies as $taxonomy ) {
			vintagejournal_add_custom_column_fields( $taxonomy );
		}
	}
}

if ( ! function_exists( 'vintagejournal_add_custom_column_fields' ) ) {
	function vintagejournal_add_custom_column_fields( $taxonomy ) {
		add_action( "{$taxonomy}_add_form_fields", 'vintagejournal_add_taxonomy_field' );
		add_action( "{$taxonomy}_edit_form_fields", 'vintagejournal_edit_taxonomy_field' );

		// Add custom columns to custom taxonomies
		add_filter( "manage_edit-{$taxonomy}_columns", 'vintagejournal_manage_category_columns' );
		add_filter( "manage_{$taxonomy}_custom_column", 'vintagejournal_manage_category_columns_fields', 10, 3 );
	}
}

function vintagejournal_get_category_image( $atts = array(), $onlysrc = false ) {
	$params = array_merge(array(
			'size'    => 'full',
			'term_id' => null,
			'alt'     => null,
	), $atts);

	$term_id = $params['term_id'];
	$size    = $params['size'];

	if ( ! $term_id ) {
		if ( is_category() ) {
			$term_id = get_query_var( 'cat' );
		} elseif ( is_tax() ) {
			$current_term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );
			$term_id = $current_term->term_id;
		}
	}

	if ( ! $term_id ) {
		return;
	}

	$attachment_id   = get_option( 'categoryimage_' . $term_id );

	$attachment_meta = get_post_meta( $attachment_id, '_wp_attachment_image_alt', true );
	$attachment_alt  = trim( strip_tags( $attachment_meta ) );

	$attr = array(
		'alt' => (is_null( $params['alt'] ) ?  $attachment_alt : $params['alt']),
	);

	if ( $onlysrc == true ) {
		$src = wp_get_attachment_image_src( $attachment_id, $size, false );
		return is_array( $src ) ? $src[0] : null;
	}

	return wp_get_attachment_image( $attachment_id, $size, false, $attr );
}


function vintagejournal_save_image( $term_id ) {
	$attachment_id = isset( $_POST['categoryimage_attachment'] ) ? (int) $_POST['categoryimage_attachment'] : null;

	if ( ! is_null( $attachment_id ) && $attachment_id > 0 && ! empty( $attachment_id ) ) {
		update_option( 'categoryimage_' . $term_id, $attachment_id );
		return;
	}

	delete_option( 'categoryimage_' . $term_id );
}

function vintagejournal_get_attachment_id( $term_id ) {
	return get_option( 'categoryimage_' . $term_id );
}

function vintagejournal_has_image( $term_id ) {
	return (vintagejournal_get_attachment_id( $term_id ) !== false);
}

function vintagejournal_add_taxonomy_field( $taxonomy ) {
	echo vintagejournal_taxonomy_field( 'add-form-option-image', $taxonomy );
}

function vintagejournal_edit_taxonomy_field( $taxonomy ) {
	echo vintagejournal_taxonomy_field( 'edit-form-option-image', $taxonomy );
}

function vintagejournal_taxonomy_field( $template, $taxonomy ) {
	$params = array(
		'label'  => array(
			'image'        => esc_html__( 'Image', 'vintagejournal' ),
			'upload_image' => esc_html__( 'Upload/Edit Image', 'vintagejournal' ),
			'remove_image' => esc_html__( 'Remove image', 'vintagejournal' ),
		),
		'categoryimage_attachment' => null,
	);

	if ( isset( $taxonomy->term_id ) && vintagejournal_has_image( $taxonomy->term_id ) ) {
		$image = vintagejournal_get_category_image(array(
			'term_id' => $taxonomy->term_id,
		), true);

		$attachment_id = vintagejournal_get_attachment_id( $taxonomy->term_id );

		$params = array_replace_recursive($params, array(
			'categoryimage_image'      => $image,
			'categoryimage_attachment' => $attachment_id,
		));
	}

	return vintagejournal_get_template( $template, $params, false );
}

function vintagejournal_manage_category_columns( $columns ) {
	$columns['image'] = esc_html__( 'Image', 'vintagejournal' );
	return $columns;
}

function vintagejournal_manage_category_columns_fields( $deprecated, $column_name, $term_id ) {
	if ( $column_name == 'image' && vintagejournal_has_image( $term_id ) ) {
		echo esc_utl(vintagejournal_get_category_image(array(
			'term_id' => $term_id,
			'size'    => 'thumbnail',
		)));
	}
}

if ( ! function_exists( 'vintagejournal_get_template' ) ) {
	function vintagejournal_get_template( $name, $params = array(), $echo_html = true ) {
		$filename = get_template_directory() . '/template-parts/' . $name . '.php';

		if ( ! file_exists( $filename ) ) {
			return;
		}

		foreach ( $params as $param => $value ) {
			$$param = $value;
		}

		ob_start();
		include $filename;
		$html = ob_get_contents();
		ob_end_clean();

		if ( ! $echo_html ) {
			return $html;
		}

		echo wp_kses( $html, wp_kses_allowed_html( 'post' ) );

	}
}
function vintagejournal_related_post_home() {
	global $post;
	$categories = get_the_category();
	if ( $categories ) {
		foreach ( $categories as $category ) {
			$cat[] = $category->cat_ID;
		}
			$args = array(
			'cat' => $cat,
			'order' => 'DESC',
			'orderby' => 'rand',
			'post__not_in' => array( $post->ID ),
			'posts_per_page' => 3,
		);
		$related_query = null;
		$related_query = new WP_Query( $args );
		if ( $related_query->have_posts() ) {
			echo '<div class="like-post">
		<h3>' . __( 'You may also like','vintagejournal' ) . '</h3>
		<ul>';
			while ( $related_query->have_posts() ) : $related_query->the_post();
				global $post;
				$related_category = get_the_category( $post->ID );
				echo '<li><a href="' . esc_url( get_the_permalink() ) . '">';

				if ( has_post_thumbnail() ) {
					echo '<img src="' . esc_url( get_the_post_thumbnail_url( $post->ID,'vintagejournal-post-medium' ) ) . '" />';
				}

				echo '</a>
				<p class="category">';
				if ( ! empty( $related_category ) ) {
					$count = count( $related_category );
					$flag = 1;
					foreach ( $related_category as $cat ) {
						$span = '<span class="hr">/</span>';
						if ( $flag == $count ) { $span = ''; }
						echo '<a href="' . esc_url( get_term_link( $cat->term_id ) ) . '">' . esc_html( $cat->name ) . '</a>' . wp_kses( $span, wp_kses_allowed_html( 'post' ) );
						$flag++;
					}
				}
				echo '</p>
				<p class="title"><a rel="bookmark" href="' . esc_url( get_the_permalink() ) . '">' . esc_attr( get_the_title() ) . '</a></p>
				</li>';
			endwhile;
			echo '</ul></div>';
		}
	}// End if().
	wp_reset_postdata();
	wp_reset_query();
}

// Create Breadcrumbs for our theme
function vintagejournal_breadcrumbs() {

		  // Settings
	$home_title         = esc_html( 'Home','vintagejournal' );

		  // If you have any custom post types with custom taxonomies, put the taxonomy name below (e.g. product_cat)
	$custom_taxonomy    = 'product_cat';

		   // Get the query & post information
	global $post,$wp_query;

		   // Do not display on the homepage
	if ( ! is_front_page() ) {

			  // Build the breadcrums
		echo '<div class="breadcrumb"><div class="row"><p>';

				   // Home page
		echo '<a href="' . esc_url( get_home_url() ) . '" title="' . esc_attr( $home_title ) . '">' . esc_attr( $home_title ) . '</a><i class="fa fa-angle-double-right"></i>';

				  $prefix = '';

		if ( is_archive() && ! is_tax() && ! is_category() && ! is_tag() && ! is_author() ) {

						  echo '<span>' . esc_attr( post_type_archive_title( $prefix, false ) ) . '</span>';

		} elseif ( is_archive() && is_tax() && ! is_category() && ! is_tag() ) {

			// If post is a custom post type
			$post_type = get_post_type();

			// If it is a custom post type display name and link
			if ( $post_type != 'post' ) {

								  $post_type_object = get_post_type_object( $post_type );
				$post_type_archive = get_post_type_archive_link( $post_type );

							  echo '<a href="' . esc_url( $post_type_archive ) . '" title="' . esc_attr( $post_type_object->labels->name ) . '">' . esc_html( $post_type_object->labels->name ) . '</a><i class="fa fa-angle-double-right"></i>';
			}

			$custom_tax_name = get_queried_object()->name;
			echo '<span>' . esc_html( $custom_tax_name ) . '</span>';

		} elseif ( is_single() ) {

			// If post is a custom post type
			$post_type = get_post_type();

			// If it is a custom post type display name and link
			if ( $post_type != 'post' ) {

								  $post_type_object = get_post_type_object( $post_type );
				$post_type_archive = get_post_type_archive_link( $post_type );

							  echo '<a href="' . esc_url( $post_type_archive ) . '" title="' . esc_attr( $post_type_object->labels->name ) . '">' . esc_html( $post_type_object->labels->name ) . '</a><i class="fa fa-angle-double-right"></i>';

			}

			// Get post category info
			$category = get_the_category();

			if ( ! empty( $category ) ) {

				// Get last category post is in
				$last_category = array_values( $category );

				$last_category = $last_category[0];

					// Get parent any categories and create array
				$get_cat_parents = rtrim( get_category_parents( $last_category->term_id, true, ',' ),',' );
				$cat_parents = explode( ',',$get_cat_parents );

					// Loop through parent categories and store in variable $cat_display
				$cat_display = '';
				foreach ( $cat_parents as $parents ) {
					$cat_display .= $parents . '<i class="fa fa-angle-double-right"></i>';
				}
			}

			// If it's a custom post type within a custom taxonomy
			$taxonomy_exists = taxonomy_exists( $custom_taxonomy );
			if ( empty( $last_category ) && ! empty( $custom_taxonomy ) && $taxonomy_exists ) {

								   $taxonomy_terms = get_the_terms( $post->ID, $custom_taxonomy );
				$cat_id         = $taxonomy_terms[0]->term_id;
				$cat_nicename   = $taxonomy_terms[0]->slug;
				$cat_link       = get_term_link( $taxonomy_terms[0]->term_id, $custom_taxonomy );
				$cat_name       = $taxonomy_terms[0]->name;

			}

			// Check if the post is in a category
			if ( ! empty( $last_category ) ) {

				echo wp_kses( $cat_display, wp_kses_allowed_html( 'post' ) );
				echo '<span>' . esc_html( get_the_title() ) . '</span>';

								  // Else if post is in a custom taxonomy
			} elseif ( ! empty( $cat_id ) ) {

								  echo '<a href="' . esc_url( $cat_link ) . '" title="' . esc_attr( $cat_name ) . '">' . esc_html( $cat_name ) . '</a><i class="fa fa-angle-double-right"></i></a>';
				echo '<span>' . esc_html( get_the_title() ) . '</span>';

			} else {

					echo '<span>' . esc_html( get_the_title() ) . '</span>';

			}
		} elseif ( is_category() ) {

			// Category page
			echo '<span>' . esc_html( single_cat_title( '', false ) ) . '</span>';

		} elseif ( is_page() ) {

			// Standard page
			if ( $post->post_parent ) {

								   // If child page, get parents
				$anc = get_post_ancestors( $post->ID );

								   // Get parents in the right order
				$anc = array_reverse( $anc );

									$parents = '';

				// Parent page loop
				foreach ( $anc as $ancestor ) {
					$parents .= '<a href="' . esc_url( get_permalink( $ancestor ) ) . '" title="' . esc_attr( get_the_title( $ancestor ) ) . '">' . esc_html( get_the_title( $ancestor ) ) . '</a><i class="fa fa-angle-double-right"></i>';
				}

								   // Display parent pages
				echo wp_kses( $parents, wp_kses_allowed_html( 'post' ) );

								   // Current page
				echo '<span>' . esc_html( get_the_title() ) . '</span>';

			} else {

				// Just display current page if not parents
				echo '<span>' . esc_html( get_the_title() ) . '</span>';

			}
		} elseif ( is_tag() ) {

			// Tag page

			// Get tag information
			$term_id        = get_query_var( 'tag_id' );
			$taxonomy       = 'post_tag';
			$args           = 'include=' . $term_id;
			$terms          = get_terms( $taxonomy, $args );
			$get_term_id    = $terms[0]->term_id;
			$get_term_slug  = $terms[0]->slug;
			$get_term_name  = $terms[0]->name;

			// Display the tag name
			echo '<span>' . esc_html( $get_term_name ) . '</span>';

		} elseif ( is_day() ) {

				// Day archive

				// Year link
			echo '<a href="' . esc_url( get_year_link( get_the_time( 'Y' ) ) ) . '" title="' . esc_attr( get_the_time( 'Y' ) ) . '">' . get_the_time( 'Y' ) . esc_html__( 'Archives','vintagejournal' ) . ' </a><i class="fa fa-angle-double-right"></i>';

				// Month link
			echo '<a href="' . get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ) . '" title="' . get_the_time( 'M' ) . '">' . get_the_time( 'M' ) . esc_html__( 'Archives','vintagejournal' ) . ' </a><i class="fa fa-angle-double-right"></i>';

				// Day display
			echo '<span>' . get_the_time( 'jS' ) . ' ' . get_the_time( 'M' ) . esc_html__( 'Archives','vintagejournal' ) . ' </span>';

		} elseif ( is_month() ) {

			// Month Archive

			// Year link
			echo '<a href="' . esc_url( get_year_link( get_the_time( 'Y' ) ) ) . '" title="' . esc_attr( get_the_time( 'Y' ) ) . '">' . get_the_time( 'Y' ) . esc_html__( 'Archives','vintagejournal' ) . ' </a><i class="fa fa-angle-double-right"></i>';

			// Month display
			echo '<span>' . get_the_time( 'M' ) . esc_html__( 'Archive','vintagejournal' ) . '</span>';

		} elseif ( is_year() ) {

			// Display year archive
			echo '<span>' . get_the_time( 'Y' ) . esc_html__( 'Archives','vintagejournal' ) . '</span>';

		} elseif ( is_author() ) {

			// Auhor archive
			// Get the author information
			global $author;
			$userdata = get_userdata( $author );

			// Display author name
			echo '<span>' . esc_html__( 'Archives','vintagejournal' ) . ' ' . $userdata->display_name . '</span>';

		} elseif ( get_query_var( 'paged' ) ) {

				// Paginated archives
			echo '<span>' . esc_html__( 'Page','vintagejournal' ) . ' ' . get_query_var( 'paged' ) . '</span>';

		} elseif ( is_search() ) {

			// Search results page
			echo '<span">' . esc_html__( 'Search results for:','vintagejournal' ) . ' ' . get_search_query() . '</span>';

		} elseif ( is_404() ) {

				// 404 page
			echo '<span>' . esc_html__( 'Error 404','vintagejournal' ) . '</span>';
		}// End if().

			   echo '</p></div></div>';

	}// End if().

}

/* Show all free themes at "Download More Themes!" section in backend */
add_action( 'vintagejournal_free_themes','vintagejournal_free_themes' );
if ( ! function_exists( 'vintagejournal_free_themes' ) ) {
	function vintagejournal_free_themes() {
		global $wp_version;

		if ( false === ( $response = get_transient( '_tevolution_free_themes' ) ) ) {
			$response = wp_remote_get( '//templatic.net/api/templatic-free-themes.xml', array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'sslverify' => false, /* when curl doesn't support ssl */
				'user-agent' => 'WordPress/' . @$wp_version . '; ' . home_url(),
				'cookies' => array(),
				)
			);
			set_transient( '_tevolution_free_themes', $response, 12 * HOUR_IN_SECONDS );
		}

		/* get responase */
		if ( ! is_wp_error( $response ) ) {
			$data = $response['body'];
		}

		/* read data from xml file */
		if ( $data ) {
			$doc = new DOMDocument();
			@$doc->loadXML( $data );
			$sourceNode = $doc->getElementsByTagName( 'templatic-free-theme' );
		}

		if ( $sourceNode ) {

			echo '<div class="theme-list">';

			foreach ( $sourceNode as $source ) {

				/* get theme name */
				$theme_name = $source->getElementsByTagName( 'theme-name' );
				$name = $theme_name->item( 0 )->nodeValue;

				/* get theme image url */
				$theme_image = $source->getElementsByTagName( 'theme-image' );
				$image = $theme_image->item( 0 )->nodeValue;

				/* get theme description */
				$theme_description = $source->getElementsByTagName( 'theme-description' );
				$description = $theme_description->item( 0 )->nodeValue;

				/* get theme sale's page url */
				$theme_salespage_url = $source->getElementsByTagName( 'theme-salespage-url' );
				$theme_salespage = $theme_salespage_url->item( 0 )->nodeValue;

				echo '<div class="array-theme">';
				echo '<div class="theme-image">';
					echo '<a href="' . $theme_salespage . '" class="theme-link"><img alt="' . $name . '" src="' . $image . '"></a>';
				echo '</div>';
				echo '<h3><a href="' . $theme_salespage . '"> ' . $name . ' </a></h3>';
				echo '<p>' . $description . '</p>';
				echo '</div>';

			}

			echo '</div>';
		}// End if().

	}
}// End if().


/* Show all free plugin at "Download More Free Plugins!" section in backend */
add_action( 'vintagejournal_free_plugins','vintagejournal_free_plugins' );
if ( ! function_exists( 'vintagejournal_free_plugins' ) ) {
	function vintagejournal_free_plugins() {
		global $wp_version;

		if ( false === ( $response = get_transient( '_vintagejournal_free_plugins' ) ) ) {
			$response = wp_remote_get( '//templatic.net/api/templatic-free-themes.xml', array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'sslverify' => false, /* when curl doesn't support ssl */
				'user-agent' => 'WordPress/' . @$wp_version . '; ' . home_url(),
				'cookies' => array(),
				)
			);
			set_transient( '_vintagejournal_free_plugins', $response, 12 * HOUR_IN_SECONDS );
		}

		/* get responase */
		if ( ! is_wp_error( $response ) ) {
			$data = $response['body'];
		}

		/* read data from xml file */
		if ( $data ) {
			$doc = new DOMDocument();
			@$doc->loadXML( $data );
			$sourceNode = $doc->getElementsByTagName( 'templatic-free-plugin' );
		}

		if ( $sourceNode ) {

			echo '<div class="theme-list">';

			foreach ( $sourceNode as $source ) {

				/* get plugin name */
				$plugin_name = $source->getElementsByTagName( 'plugin-name' );
				$name = $plugin_name->item( 0 )->nodeValue;

				/* get plugin image url */
				$plugin_image = $source->getElementsByTagName( 'plugin-image' );
				$image = $plugin_image->item( 0 )->nodeValue;

				/* get plugin description */
				$plugin_description = $source->getElementsByTagName( 'plugin-description' );
				$description = $plugin_description->item( 0 )->nodeValue;

				/* get plugin sale's page url */
				$plugin_salespage_url = $source->getElementsByTagName( 'plugin-salespage-url' );
				$plugin_salespage = $plugin_salespage_url->item( 0 )->nodeValue;

				echo '<div class="array-theme">';
				echo '<div class="theme-image">';
					echo '<a href="' . $plugin_salespage . '" class="theme-link"><img alt="' . $name . '" src="' . $image . '"></a>';
				echo '</div>';
				echo '<h3><a href="' . $plugin_salespage . '"> ' . $name . ' </a></h3>';
				echo '<p>' . $description . '</p>';
				echo '</div>';

			}

			echo '</div>';
		}// End if().

	}
}// End if().

add_action( 'vintagejournal_help','vintagejournal_help_tab' );
if ( ! function_exists( 'vintagejournal_help_tab' ) ) {
	function vintagejournal_help_tab() {

		if ( false === ( $response = get_transient( '_vintagejournal_free_themes' ) ) ) {
			$response = wp_remote_get( '//templatic.net/api/templatic-free-themes.xml', array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking' => true,
				)
			);
			set_transient( '_vintagejournal_free_themes', $response, 12 * HOUR_IN_SECONDS );
		}

		if ( false === ( $response = get_transient( '_vintagejournal_free_themes' ) ) ) {
			$response = wp_remote_get( '//templatic.net/api/templatic-free-themes.xml', array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking' => true,
				)
			);
			set_transient( '_vintagejournal_free_themes', $response, 12 * HOUR_IN_SECONDS );
		}

		if ( is_wp_error( $response ) ) {
				//echo '<div id="standalone_plugin_error" class="metabox-holder wrapper widgets-holder-wrap">';
				//printf( __( '<strong>templatic.com connect Error</strong>: %s','vintagejournal' ), $response->get_error_message() );
		} else {
			$data = $response['body'];
		}

		if ( $data ) {
			$doc = new DOMDocument();
			@$doc->loadXML( $data );
			$sourceNode = $doc->getElementsByTagName( 'vintagejournal-theme-info' );
		}

		if ( $sourceNode ) {

			foreach ( $sourceNode as $source ) {
				$plugin_description = $source->getElementsByTagName( 'vintagejournal-info-description' );
				echo $short_description = $plugin_description->item( 0 )->nodeValue;
			}
		}

	}
}// End if().

/* color customizer css */
function vintagejournal_color_css() {
	global $color_data;

	require get_template_directory() . '/front-style.php';
	/* Customizer css */

	if ( isset( $color_data ) && $color_data != '' ) {
		wp_add_inline_style( 'vintagejournal-style', $color_data );
	}
}

add_action( 'wp_enqueue_scripts', 'vintagejournal_color_css' );

function vintagejournal_autoinstall_box() {
	global $wpdb;

	$post_counts = $wpdb->get_var( $wpdb->prepare( "select count(p.ID) from $wpdb->posts p join $wpdb->postmeta pm on pm.post_id=p.ID where (meta_key=%s || meta_key=%s || meta_key=%s) and (meta_value=%d || meta_value=%s)",'pt_dummy_content','tl_dummy_content','auto_install',1,'auto_install' ) );

	/* help links */
	$menu_msg1 = "<ul><li><a href='" . esc_url( home_url( '/wp-admin/customize.php' ) ) . "'>" . esc_html__( 'Add your logo', 'vintagejournal' ) . ' </a></li>';
	$menu_msg1 .= "<li><a href='" . esc_url( home_url( '/wp-admin/customize.php' ) ) . "'>" . esc_html__( 'Change site colors', 'vintagejournal' ) . ' </a></li>';
	$menu_msg1 .= "<li><a href='" . esc_url( home_url( '/wp-admin/nav-menus.php?action=edit' ) ) . "'>" . esc_html__( 'Manage menu navigation', 'vintagejournal' ) . '</a></li>';
	$menu_msg1 .= "<li><a href='" . esc_url( home_url( '/wp-admin/widgets.php' ) ) . "'>" . esc_html__( 'Manage sidebar widgets ', 'vintagejournal' ) . ' </a></li></ul>';

	$menu_msg2 = "<ul><li><a href='" . esc_url( home_url( '/wp-admin/post-new.php' ) ) . "'>" . esc_html__( 'Add a Music', 'vintagejournal' ) . '</a></li>';
	$menu_msg2 = "<ul><li><a href='" . esc_url( home_url( '/wp-admin/post-new.php' ) ) . "'>" . esc_html__( 'Add a Event', 'vintagejournal' ) . '</a></li>';
	$menu_msg2 = "<ul><li><a href='" . esc_url( home_url( '/wp-admin/post-new.php' ) ) . "'>" . esc_html__( 'Add a Blog', 'vintagejournal' ) . '</a></li>';
	$menu_msg2 .= "<li><a href='" . esc_url( home_url( '/wp-admin/post-new.php?post_type=page' ) ) . "'>" . esc_html__( 'Setup pages', 'vintagejournal' ) . '</a></li></ul>';

	$my_theme = wp_get_theme();
	$theme_name = $my_theme->get( 'Name' );
	$version = $my_theme->get( 'Version' );

	$dummydata_title = '';
	$dummy_data_msg = '';
	$dummy_theme_message = '';
	$dummydata_title .= '<h3 class="twp-act-msg">' . sprintf( wp_kses( 'Thank you. %s (<small>v</small> %s) is now activated.', 'vintagejournal',array( 'small' ) ), @wp_get_theme(), strtolower( $version ) ) . ' <a href="' . esc_url( home_url( '/' ) ) . '">Visit Your Site</a></h3>';

	/* system info goes in this filter */
	$dummydata_title = apply_filters( 'vintagejournal_after_install_delete_button', $dummydata_title );

	/* guilde and support link */

	$dummy_data_msg .= apply_filters( 'vintagejournal_after_install_delete_button', $dummy_data_msg );

	if ( $post_counts > 0 ) {

		$theme_name = get_option( 'stylesheet' );

		$dummy_data_msg = '';

		$dummy_data_msg = $dummydata_title;

		$dummy_data_text_msg = '
			
			<h4><span id="success_msg_install">' . esc_html__( 'All done. Your site is ready with sample data now.', 'vintagejournal' ) . ' <a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'Visit your site', 'vintagejournal' ) . '</a>.</span>
			<p>' . esc_html__( 'To make further adjustments to your site simply visit the', 'vintagejournal' ) . ' <a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'homepage', 'vintagejournal' ) . '</a></p></h4><hr>
			<div id="install-notification" ><h4 id="install_message">' . esc_html__( 'Wish to delete sample data?', 'vintagejournal' ) . ' </h4><p>' . esc_html__( 'Please note that deleting sample data will also remove any content you may have added or edited on any sample content. Deleting the sample data will also remove all sample widgets which were inserted.', 'vintagejournal' ) . '</p><span><h4>' . esc_html__( 'I understand.', 'vintagejournal' ) . ' <a class="button button-primary delete-data-button" href="' . esc_url( home_url( '/' ) ) . 'wp-admin/themes.php?page=editor-getting-started&dummy=del">' . esc_html__( 'Delete sample data', 'vintagejournal' ) . '</a></h4></span>';

		$dummy_data_text_msg .= '<span id="install-notification-nonce" class="hidden">' . esc_attr( wp_create_nonce( 'install-notification-nonce' ) ) . '</span></div>';

		$dummy_data_msg .= $dummy_theme_message;

	} else {

		$theme_name = get_option( 'stylesheet' );

		$dummy_data_msg = '';

		$dummy_data_msg = $dummydata_title;

		$dummy_data_text_msg = '<div id="install-notification" class="tmpl-auto-install-yb"><h4>' . esc_html__( 'Your site not looking like our online demo?', 'vintagejournal' ) . ' </h4> <span><a class="button button-primary" href="' . esc_url( home_url( '/' ) ) . 'wp-admin/themes.php?page=editor-getting-started&dummy_insert=1">' . esc_html__( 'Install sample data', 'vintagejournal' ) . '</a></span> <p>' . esc_html__( 'So that you don&prime;t start on a blank site, the sample data will help you get started with the theme. The content includes some default settings, widgets in their locations, pages, posts and a few dummy posts.', 'vintagejournal' ) . '</p>';

		$dummy_data_text_msg .= '<span id="install-notification-nonce" class="hidden">' . esc_attr( wp_create_nonce( 'install-notification-nonce' ) ) . '</span></div>';

		$dummy_data_msg .= $dummy_theme_message;
	}

	$theme_name = get_option( 'stylesheet' );

	$dummy_data_msg = '';
	$dummy_data_msg_l = '';
	$dummy_data_msg = $dummydata_title;

	$licencekey_frm = '<h2>' . esc_html__( 'Your site not looking like our online demo?', 'vintagejournal' ) . '</h2><div class="sample-data-wrap">' . $dummy_data_text_msg . do_action( 'vintagejournal_error_message' ) . '</div>';

	$dummy_data_msg .= '

		<form action="#" name="" method="post">

		<div class="form-table">

			<div class="theme-step">

				<div class="licence-key">

					' . $licencekey_frm . '

					</div>	';

	$dummy_data_msg .= '</div>';

	$dummy_data_msg .= "<div class='sample-data'>" . $dummy_theme_message . '</div></div>';
	$dummy_data_msg .= '</form>';

	 echo '<div id="ajax-notification" class="welcome-panel tmpl-welcome-panel"><div class="welcome-panel-content">' . $dummy_data_msg . '</div></div>';

	/* Delete the dummy data */
	if ( isset( $_REQUEST['dummy'] ) && $_REQUEST['dummy'] == 'del' ) {
		vintagejournal_delete_dummy_data();
		update_option( 'listing_xml', 0 );
		$url = admin_url() . 'themes.php';
		wp_redirect( admin_url() . 'themes.php?page=editor-getting-started' );
	}

	if ( isset( $_REQUEST['dummy_insert'] ) && $_REQUEST['dummy_insert'] == 1 ) {

		$theme_name = str_replace( ' ', '', strtolower( wp_get_theme() ) );

		wp_redirect( esc_url( admin_url( '/' ) . 'themes.php?page=editor-getting-started&x=y' ) );
	}
}
add_action( 'admin_init','vintagejournal_auto_install_xml_file' );
/*	include xml file for auto install. */
function vintagejournal_auto_install_xml_file() {
	if ( isset( $_REQUEST['dummy_insert'] ) && $_REQUEST['dummy_insert'] ) {

		/* check if theme specific auto install file is exists or not */
		if ( file_exists( get_template_directory() . '/inc/admin/auto-install/auto_install_xml.php' ) ) {

			require_once( get_template_directory() . '/inc/admin/auto-install/auto_install_xml.php' );

		}
	}
}



?>
