<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package vintagejournal
 */

if ( ! function_exists( 'vintagejournal_posted_on' ) ) :
	/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
	function vintagejournal_posted_on() {
		global $post;
		$author = get_userdata( $post->post_author );
		$author_url = get_site_url() . '/author/' . $author->user_login;
		$byline = sprintf(
			esc_html_x( '%s', 'post author', 'vintagejournal' ),
			'<span class="author vcard" itemprop="author" itemscope itemtype="https://schema.org/Person"><span itemprop="name">by <a class="url fn n" href="' . esc_url( $author_url ) . '">' . esc_html( $author->display_name ) . '</a></span></span>'
		);
		if ( ! is_single() ) {
			vintagejournal_categories_tags();
		}
			echo '  <span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

	}
endif;

function vintagejournal_categories_tags() {
	global $post;

	$taxonomies = get_object_taxonomies( (object) array(
		'post_type' => $post->post_type,
		'public' => true,
		'_builtin' => true,
	) );
	$taxonomy_category = '';
	$terms = get_the_terms( $post->ID, $taxonomies[0] );
	$sep = "<span class='hr'>/</span>";
	$i = 0;
	if ( ! empty( $terms ) ) {
		//if(!empty($terms)){
		foreach ( $terms as $term ) {
			if ( $i == ( count( $terms ) - 1) ) {
				$sep = '';
			} elseif ( $i == ( count( $terms ) - 2) ) {
				$sep = __( ' <span class="hr">/</span> ','vintagejournal' );
			}
			$term_link = get_term_link( $term, $taxonomies[0] );
			if ( is_wp_error( $term_link ) ) {
				continue;
			}
			$taxonomy_category .= '<a href="' . esc_url( $term_link ) . '">' . esc_html( $term->name ) . '</a>' . $sep;
			$i++;
		}

		 echo '<span class="cate"> ' . wp_kses( $taxonomy_category, wp_kses_allowed_html( 'post' ) ) . '</span>';
		echo '</span>';
	}

}





if ( ! function_exists( 'vintage_content_nav' ) ) :
	/**
 * Display navigation to next/previous pages when applicable.
 */
	function vintage_content_nav( $nav_id ) {
		global $wp_query, $post;

		// Don't print empty markup on single pages if there's nowhere to navigate.
		if ( is_single() ) {
			$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
			$next = get_adjacent_post( false, '', false );

			if ( ! $next && ! $previous ) {
				return;
			}
		}

		// Don't print empty markup in archives if there's only one page.
		if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) ) {
			return;
		}

		$nav_class = ( is_single() ) ? 'post-navigation' : 'paging-navigation';

		?>
		<nav id="<?php echo esc_attr( $nav_id ); ?>" class="clearfix <?php echo esc_attr( $nav_class ); ?>" role="navigation">
		<?php if ( is_single() ) : ?>
		<?php $prev_post = get_previous_post();
		$next_post = get_next_post();

		if ( empty( $next_post ) ) :
			$next_id = '';
		else :
			$next_id = $next_post->ID;
		endif;
		if ( empty( $prev_post ) ) :
			$prev_id = '';
		else :
			$prev_id = $prev_post->ID;
		endif;
		?>
		<?php previous_post_link( '<div class="nav-previous"><img src="' . esc_url( get_the_post_thumbnail_url( $prev_id,'vintagejournal-post-small-thumb',array( 101, 78 ) ) ) . '"/> %link</div>', '<span class="meta-nav"> <i class="fa fa-angle-left"></i>' . esc_html__( ' Previous Article','vintagejournal' ) . '</span> %title' ); ?>
		<?php next_post_link( '<div class="nav-next"><img src="' . esc_url( get_the_post_thumbnail_url( $next_id,'vintagejournal-post-small-thumb' ) ) . '"/> %link</div>', '<span class="meta-nav">' . esc_html__( 'Next Article ', 'vintagejournal' ) . '<i class="fa fa-angle-right"></i></span> %title' ); ?>

	<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : ?>

		<?php if ( get_next_posts_link() ) : ?>
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav"><i class="fa fa-chevron-left"></i></span> Previous Articles', 'vintagejournal' ) ); ?></div>
		<?php endif; ?>

		<?php if ( get_previous_posts_link() ) : ?>
		<div class="nav-next"><?php previous_posts_link( __( 'Next Articles <span class="meta-nav"><i class="fa fa-chevron-right"></i></span>', 'vintagejournal' ) ); ?></div>
		<?php endif; ?>

	<?php endif; ?>

		</nav><!-- #<?php echo esc_html( $nav_id ); ?> -->
		<?php
	}
endif;


if ( ! function_exists( 'vintage_entry_footer' ) ) :
	/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
	function vintage_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'vintagejournal' ) );
			if ( $categories_list && vintage_categorized_blog() ) {
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'vintagejournal' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'vintagejournal' ) );
			if ( $tags_list ) {
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'vintagejournal' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link( esc_html__( 'Leave a comment', 'vintagejournal' ), esc_html__( '1 Comment', 'vintagejournal' ), esc_html__( '% Comments', 'vintagejournal' ) );
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				/* translators: %s: Name of current post */
				esc_html__( 'Edit %s', 'vintagejournal' ),
				the_title( '<span class="screen-reader-text">"', '"</span>', false )
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function vintage_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'vintage_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'vintage_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so vintage_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so vintage_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in vintage_categorized_blog.
 */
function vintage_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'vintage_categories' );
}
add_action( 'edit_category', 'vintage_category_transient_flusher' );
add_action( 'save_post',     'vintage_category_transient_flusher' );
