<?php
/*
 * Home Page Post Slider
 */

if ( ! class_exists( 'Vintagejournal_Post_Slider' ) ) {

	class Vintagejournal_Post_Slider extends WP_Widget {

		/**
		 * Sets up a new Post Slider widget instance.
		 */

		function __construct() {
			/* Constructor */
			$widget_ops = array(
				'classname' => 'vintagejournal_post_slider',
				'description' => esc_html__( 'Display images from a specific category. The widget works best in the Homepage Banner area.','vintagejournal' ),
			);
			parent::__construct( 'vintagejournal_post_slider', esc_html__( 'T &rarr; Post Slider','vintagejournal' ), $widget_ops );
		}

		function widget( $args, $instance ) {
			/* print the widget on front end */

			$category 	 = empty( $instance['category'] ) ? '' : $instance['category'];
			$number 	 = empty( $instance['number'] ) ? '' : $instance['number'];

			echo wp_kses( $args['before_widget'], wp_kses_allowed_html( 'post' ) );

			/* if any category is selected then get posts from that categories, otherwise get all posts */
			if ( ! empty( $category ) ) {
					  $slider_args = array(
								'post_type' => 'post',
								'posts_per_page' => $number,
								'post_status' => 'publish',
								'tax_query' => array(
										array(
											'taxonomy' => 'category',
											'field' => 'slug',
											'terms' => $category,
										),
									),
					  );
			} else {
					$slider_args = array(
				'post_type' => 'post',
							'post_status' => 'publish',
							'posts_per_page' => $number,
						);
			}

			$post_query = null;
			$post_query = new WP_Query( $slider_args );

			if ( $post_query->have_posts() ) {
				echo '<div class="home-top-slider">
						<div id="owl-header" class="owl-carousel">';
				while ( $post_query->have_posts() ) : $post_query->the_post();
					global $post;
						echo '<div class="item">';
									$image_html = '<a href="' . get_the_permalink() . '">';
									$category = get_the_category( $post->ID );
					if ( has_post_thumbnail() ) {
						$image_html .= '<img src="' . esc_url( get_the_post_thumbnail_url( $post->ID,'vintagejournal-slider-image' ) ) . '" /></a>';
					}

									$total_view = get_post_meta( $post->ID,'vintagejournal_total_post_view','true' );
					if ( trim( $total_view ) == '' ) {
						$total_view = 0;
					}
									echo '<div class="post-info"><p class="post-meta"><span class="date">' . get_the_time( 'M' ) . ' ' . get_the_time( 'd' ) . ', ' . get_the_time( 'Y' ) . '</span><span class="meta-r"><i class="fa fa-eye"></i> ' . $total_view . '   <i class="fa fa-comment"></i>';

									comments_popup_link( esc_html__( '0', 'vintagejournal' ), esc_html__( '1', 'vintagejournal' ), esc_html__( '%', 'vintagejournal' ) );

									echo '</span></p>
										<h3><a href="' . esc_url( get_the_permalink() ) . '">' . esc_attr( get_the_title() ) . '</a></h3>
										<p class="cate">';
					if ( ! empty( $category ) ) {
						$count = count( $category );
						$flag = 1;
						foreach ( $category as $cat ) {
							$span = '<span class="hr">/</span>';
							if ( $flag == $count ) { $span = ''; }
							echo '<a href="' . esc_url( get_term_link( $cat->term_id ) ) . '">' . esc_attr( $cat->name ) . '</a>' . wp_kses( $span, wp_kses_allowed_html( 'post' ) );
							$flag++;
						}
					}
										echo '</p>
									</div>' . $image_html . '
								</div>';
				endwhile;
				echo '</div>
						<div class="customNavigation">
							<a class="btn prev"><i class="fa fa-angle-double-left"></i></a>
							<a class="btn next"><i class="fa fa fa-angle-double-right"></i></a>
						</div>
					</div>';
			}// End if().

			echo wp_kses( $args['after_widget'], wp_kses_allowed_html( 'post' ) );
			/* Restore original Post Data */
			wp_reset_postdata();
			wp_reset_query();
		}

		/**
		 * Handles updating settings for the current Display Post widget instance.
		 */

		function update( $new_instance, $old_instance ) {
			/* save the widget */
			return $new_instance;
		}

		/**
		 * Outputs the Homepage post slider widget settings form.
		 * @param array $instance Current settings.
		 */
		function form( $instance ) {

			$category 		= isset( $instance['category'] ) ? $instance['category'] : '';
			$number 		= isset( $instance['number'] ) ? $instance['number'] : '';

			?>
			<!-- carousel sldier taxonomy fetch as per post type field -->
			<p>
			  <label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php echo esc_html__( 'Categories:', 'vintagejournal' ); ?></label>
			  <select id="<?php echo $this->get_field_id( 'category' ); ?>" name="<?php echo $this->get_field_name( 'category' ); ?>[]" class="<?php echo $this->get_field_id( 'category' ); ?> widefat" multiple="multiple">
				<option value=""><?php echo esc_html__( 'Select Category', 'vintagejournal' ); ?></option>
				<?php
				 $taxonomies = get_object_taxonomies( (object) array(
					 'post_type' => 'post',
					 'public' => true,
					 '_builtin' => true,
				 ) );
						$terms = get_terms( $taxonomies[0], 'orderby=name&hide_empty=0' );
				if ( ! empty( $terms ) ) {
					foreach ( $terms as $term ) {
						$term_value = $term->slug;
						$selected = '';
						if ( ! empty( $category ) ) {
							$selected = (in_array( $term_value, $category ) || in_array( $term->slug, $category )) ? 'selected' : '';
						}?>
								<option value="<?php echo esc_attr( $term_value ) ?>" <?php echo $selected ?>> <?php echo esc_attr( $term->name ); ?></option>
								<?php
					}
				}
					?>
			  </select>
			</p>
			
			<!-- post sldier number field -->
			<p>
			  <label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php echo esc_html__( 'Number of posts', 'vintagejournal' ); ?>:
				<input class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" min="1" value="<?php echo esc_attr( $number ); ?>" />
			  </label>
			</p>
			<?php
		}
	}
}// End if().

/* EOF */
?>
